;;; package --- summary +org.el
;;;  lexical-binding: t; -*-

;;; Commentary:
;;; Code:
(setq +todo-file "~/org/inbox.org")

(setq org-directory (expand-file-name "~/org/")
      org-journal-dir "~/org/journal/"
      org-startup-indented t
      org-agenda-files (list org-directory)
      org-pretty-entities t
      org-hide-emphasis-markers t
      org-hide-leading-stars t
      org-contacts-files '("~/org/contacts.org")
      ; attempt to return todo function to spacemacs
      evil-org-key-theme '(textobjects navigation additional insert todo)
      ;; show actually italicized text instead of /italicized text/
      org-agenda-block-separator ""
      org-fontify-whole-heading-line t
      org-fontify-done-headline t
      org-fontify-quote-and-verse-blocks t
      org-log-done 'time
      org-bullets-face-name (quote org-bullet-face)
      org-bullets-bullet-list '("■" "◆" "▲" "▶")
      org-capture-templates
          '(
            ("i" "Send to inbox" entry (file+headline "~/org/inbox.org" "Inbox")
             "* TODO %?\n")
            ("l" "Send to inbox with link" entry (file+headline "~/org/inbox.org" "Inbox")
             "* TODO %?\n  %i\n  %a")
            ("w" "Work diary entry" entry (file "~/org/work_diary.org")
              "* %u\n%?\n")
            ("n" "Add an idea" entry (file "~/org/ideas.org")
              "*  %?\nEntered on %U\n"))


      org-agenda-include-diary nil

      org-agenda-custom-commands
          '(("h" todo "HOLD")
          ("d" "Agenda + Next Actions" ((agenda) (todo "NEXT"))))

      org-tag-alist '(("@home" . ?h)
                      ("@townhall" . ?t)
                      ("@farm" . ?f)
                      ("@errand" . ?e)
                      ("@read" . ?r)
                      ("@next" . ?n)
                      ("@computer" . ?c))

      org-modules '(org-drill
                      org-id
                      org-info
                      org-habit
                      org-protocol
                      org-annotate-file
                      org-eval
                      org-expiry
                      org-contacts
                      org-man
                      org-notmuch
                      org-collector
                      org-panel
                      org-screen
                      org-toc)

        ; refile targets
      org-refile-targets '(("~/org/todo.org" :maxlevel . 2)
                           ("~/org/someday.org" :maxlevel . 2)
                           ("~/org/town.org" :maxlevel . 2)
                           ("~/org/personal.org" :maxlevel . 2)
                           ("~/org/elation.org" :maxlevel . 2)))

;; org-match-sparse-tree
;; org-set-tags-command
(defun +open-todo-file ()
  (interactive)
  "Opens the todo file"
  (find-file +todo-file))

(map!
 :leader
   :desc "Open todo file" "O" #'+open-todo-file)

(defun +show-agenda ()
  (interactive)
  (delete-other-windows)
  (with-popup-rules! nil
    (org-agenda-list)
    (calendar))
  (other-window 1)
  (split-window-vertically)
  (other-window 1)
  (find-file +todo-file))


(map! :leader
      (:prefix "o"
        :desc "Org Agenda" "a" #'org-agenda-list
        :desc "Org open link" "l" #'org-open-at-point
        :desc "Org set tags" "t" #'org-set-tags-command
        :desc "Org Agenda and Notes" "A" #'+show-agenda))
